#ifndef _INDFLAGS_H_
#define _INDFLAGS_H_

#define INDFLAG_MALE          0
#define INDFLAG_FIGHTING      1
#define INDFLAG_ATTACKPLAYER  2
#define INDFLAG_NOSTEAL       3
#define INDFLAG_SITTING       4
#define INDFLAG_SLEEPING      5
#define INDFLAG_GETSTUFF      6
#define INDFLAG_INBOAT        7
#define INDFLAG_CORPSE        8
#define INDFLAG_GHOST         9
#define INDFLAG_NIGHTVISION  10

#ifdef INDIVIDUAL_C

char *sex_possessive[] = {"his", "her", "its", NULL};
char *sex_name[] = {"Male", "Female", "Neuter", NULL};

char *indflagnames[] = {"NotUsed1", "Fighting", "AttackPlayer", "NoSteal",
       "Sitting", "Sleeping", "GetStuff", "InBoat", "Corpse", 
       "Ghost", "NightVision", NULL};

int indflagfrozen[] = {INDFLAG_FIGHTING, INDFLAG_SITTING, INDFLAG_SLEEPING,
      INDFLAG_INBOAT, INDFLAG_CORPSE, INDFLAG_GHOST, -1};

#else

extern char *indflagnames[];
extern int indflagfrozen[];

#endif
#endif




